@@ -1,5 +1,5 @@
 package Amazon::DynamoDB;
-$Amazon::DynamoDB::VERSION = '0.22';
+$Amazon::DynamoDB::VERSION = '0.24';
 # ABSTRACT: API support for Amazon DynamoDB
 use strict;
 use warnings;
@@ -40,15 +40,19 @@ Amazon::DynamoDB - API support for Amazon DynamoDB
 
 =head1 VERSION
 
-version 0.22
+version 0.24
 
 =head1 SYNOPSIS
 
   my $ddb = Amazon::DynamoDB->new(
      implementation => 'Amazon::DynamoDB::LWP',
      version        => '20120810',
+
      access_key     => 'access_key',
      secret_key     => 'secret_key',
+     # or you specify to use an IAM role
+     use_iam_role   => 1, 
+
      host => 'dynamodb.us-east-1.amazonaws.com',
      scope => 'us-east-1/dynamodb/aws4_request',
      ssl => 1,
